import {
  Component,
  OnInit,
  ChangeDetectorRef,
  Input,
  Output,
  EventEmitter
} from '@angular/core';
import { NotificationSetting } from '../models/settings';
import {
  MatRadioChange,
  MatSelectChange,
  MatCheckboxChange
} from '@angular/material';
import { NGXLogger } from 'ngx-logger';
import { NotificationMethod } from '@ucap-webmessenger/core';

@Component({
  selector: 'ucap-settings-notification',
  templateUrl: './notification.component.html',
  styleUrls: ['./notification.component.scss']
})
export class NotificationComponent implements OnInit {
  @Input()
  setting: NotificationSetting;

  @Output()
  changed = new EventEmitter<NotificationSetting>();

  NotificationMethod = NotificationMethod;

  constructor(
    private changeDetectorRef: ChangeDetectorRef,
    private logger: NGXLogger
  ) {}

  ngOnInit() {
    this.logger.debug('setting', this.setting);
  }

  onChangeUse(event: MatRadioChange) {
    this.emit({ ...this.setting, use: 'true' === event.value ? true : false });
  }

  onSelectionChangeMethod(event: MatSelectChange) {
    this.emit({ ...this.setting, method: event.value });
  }

  onSelectionChangeAlertExposureTime(event: MatSelectChange) {
    this.emit({ ...this.setting, alertExposureTime: event.value });
  }

  onChangeReceiveForMobile(event: MatCheckboxChange) {
    this.emit({ ...this.setting, receiveForMobile: event.checked });
  }

  onChangeReceiveForMessage(event: MatCheckboxChange) {
    this.emit({ ...this.setting, receiveForMessage: event.checked });
  }

  private emit(setting: NotificationSetting) {
    this.setting = setting;
    this.changed.emit(this.setting);
  }
}
